==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebMoveFloatingPaneActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebMoveFloatingPaneActionDescription } from "./WebMoveFloatingPaneActionDescription";
/**
 * @hidden
 */
export let WebMoveFloatingPaneActionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMoveFloatingPaneActionDescriptionMetadata extends Base {
        static b(a) {
            if (WebMoveFloatingPaneActionDescriptionMetadata.a == null) {
                WebMoveFloatingPaneActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMoveFloatingPaneActionDescriptionMetadata.c(WebMoveFloatingPaneActionDescriptionMetadata.a);
            }
            if (a.j(WebMoveFloatingPaneActionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebMoveFloatingPaneActionDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebPaneDragActionDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:MoveFloatingPaneAction");
            a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
            a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
            a.item("OldLocation", "ExportedType:WebDockManagerPoint");
            a.item("NewLocation", "ExportedType:WebDockManagerPoint");
        }
        static d(a) {
            WebMoveFloatingPaneActionDescriptionMetadata.b(a);
            a.aa("WebMoveFloatingPaneAction", () => new WebMoveFloatingPaneActionDescription());
            a.z("WebMoveFloatingPaneAction", WebMoveFloatingPaneActionDescriptionMetadata.a);
        }
    }
    WebMoveFloatingPaneActionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMoveFloatingPaneActionDescriptionMetadata, 'WebMoveFloatingPaneActionDescriptionMetadata');
    WebMoveFloatingPaneActionDescriptionMetadata.a = null;
    return WebMoveFloatingPaneActionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebMoveFloatingPaneActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebMoveFloatingPaneActionDescription } from "./WebMoveFloatingPaneActionDescription";
/**
 * @hidden
 */
export let WebMoveFloatingPaneActionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMoveFloatingPaneActionDescriptionMetadata extends Base {
        static b(a) {
            if (WebMoveFloatingPaneActionDescriptionMetadata.a == null) {
                WebMoveFloatingPaneActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMoveFloatingPaneActionDescriptionMetadata.c(WebMoveFloatingPaneActionDescriptionMetadata.a);
            }
            if (a.k(WebMoveFloatingPaneActionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebMoveFloatingPaneActionDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebPaneDragActionDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:MoveFloatingPaneAction");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
            a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
            a.item("OldLocation", "ExportedType:WebDockManagerPoint");
            a.item("NewLocation", "ExportedType:WebDockManagerPoint");
        }
        static d(a) {
            WebMoveFloatingPaneActionDescriptionMetadata.b(a);
            a.ac("WebMoveFloatingPaneAction", () => new WebMoveFloatingPaneActionDescription());
            a.ab("WebMoveFloatingPaneAction", WebMoveFloatingPaneActionDescriptionMetadata.a);
        }
    }
    WebMoveFloatingPaneActionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMoveFloatingPaneActionDescriptionMetadata, 'WebMoveFloatingPaneActionDescriptionMetadata');
    WebMoveFloatingPaneActionDescriptionMetadata.a = null;
    return WebMoveFloatingPaneActionDescriptionMetadata;
})();
